@@ -27,18 +27,17 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include "../meam/jammo-playing-track.h"
 
 #include "../gems/gems.h"
-
+#include <tangle.h>
 
 /*Chum is like state-machine*/
 int state_of_chum=SCREEN_WELCOME;
-int current_theme; /*for composing game*/
 char* current_song;  /*for karaoke game*/
 
 //This is not same than language from profile (which affects speech of mentor)
 //This is only when user wants sing a song in different language.
-char* selected_language="_fi";
+const char* selected_language="_fi";
 
-char* chum_get_selected_language(){
+const char* chum_get_selected_language(){
 	return selected_language;
 }
 
@@ -83,7 +82,6 @@ char *name_of_states[] ={ "SCREEN_WELCOME",
                           "SCREEN_COMMUNITYMENU",
                           "SCREEN_FROM_CUPBOARD"};
 
-static JammoSequencer* sequencer = NULL;
 
 gboolean multiplaying=FALSE; 
 gint number_of_themes = 0;
@@ -104,14 +102,25 @@ state_of_chum=state;
 
 
 
-char* chum_get_current_song(){
-cem_add_to_log(g_strdup_printf("get_current_song(). will return '%s'",current_song),LOG_DEBUG);
-    return current_song;
+const char* chum_get_current_song(){
+	gchar* s;
+	
+	s = g_strdup_printf("get_current_song(). will return '%s'", current_song);
+	cem_add_to_log(s, LOG_DEBUG);
+	g_free(s);
+
+	return current_song;
 }
 
-void chum_set_current_song(gchar* song){
-cem_add_to_log(g_strdup_printf("set_current_song(%s)",song),LOG_DEBUG);
-    current_song=song;
+void chum_set_current_song(const gchar* song){
+	gchar* s;
+	
+	s = g_strdup_printf("set_current_song(%s)", song);
+	cem_add_to_log(s, LOG_DEBUG);
+	g_free(s);
+
+	g_free(current_song);
+	current_song = g_strdup(song);
 }
 
 
@@ -125,3 +134,11 @@ return;
 }
 
 
+/*
+We often want call:
+clutter_container_foreach(CLUTTER_CONTAINER(mainview), tangle_actor_hide_animated, NULL);
+But tangle_actor_hide_animated is not 'ClutterCallback'
+*/
+void chum_hide_this_tangle_actor (ClutterActor *actor, gpointer none){
+tangle_actor_hide_animated(TANGLE_ACTOR(actor));
+}
