@@ -30,8 +30,11 @@
 #include "../gui_clutter/communitymenu.h"
 #include "../gui_clutter/gamesmenu.h"
 
+#include "../gems/gems.h"
+
 #ifdef N900
 #include <libosso.h>
+#include <clutter/x11/clutter-x11.h>
 #endif
 
 
@@ -106,6 +109,7 @@ static void add_search_paths(ClutterScript* script) {
 }
 
 #ifdef N900
+
 static gboolean pause_display_blanking(gpointer user_data) {
 	osso_context_t* osso_context;
 	
@@ -115,6 +119,38 @@ static gboolean pause_display_blanking(gpointer user_data) {
 	
 	return TRUE;
 }
+
+static gint rpc_callback(const gchar* interface, const gchar* method, GArray* arguments, gpointer user_data, osso_rpc_t* retval) {
+	ClutterStage* stage;
+	Display* display;
+	Window window;
+	XEvent event;
+
+	stage = CLUTTER_STAGE(user_data);
+	
+	if (!strcmp(interface, "org.umsic.jammo") && !strcmp(method, "top_application")) {
+		display = clutter_x11_get_default_display();
+		window = clutter_x11_get_stage_window(stage);
+
+		XRaiseWindow(display, window);
+		/* Fremantle window manager does not obey XRaiseWindow, but reacts on _NET_ACTIVE_WINDOW messages. */
+		event.xclient.type = ClientMessage;
+		event.xclient.message_type = XInternAtom(display, "_NET_ACTIVE_WINDOW", False);
+		event.xclient.display = display;
+		event.xclient.window = window;
+		event.xclient.format = 32;
+		event.xclient.data.l[0] = 1;
+		event.xclient.data.l[1] = clutter_x11_get_current_event_time();
+		event.xclient.data.l[2] = None;
+		event.xclient.data.l[3] = 0;
+		event.xclient.data.l[4] = 0;
+		XSendEvent(display, clutter_x11_get_root_window(), False, SubstructureNotifyMask | SubstructureRedirectMask, &event);
+	}
+	
+	retval->type = DBUS_TYPE_INVALID;
+	
+	return OSSO_OK;
+}
 #endif
 
 /* Be sure there are needed place to save compositions and singings.
@@ -140,7 +176,6 @@ int main(int argc, char** argv) {
 	osso_context_t* osso_context;
 #endif
 
-	GType type;
 	TangleStylesheet* stylesheet;
 	gchar* filename;
 	ClutterActor* stage;
@@ -151,6 +186,15 @@ int main(int argc, char** argv) {
 	
 	jammo_meam_init(&argc, &argv);
 	jammo_chum_init(&argc, &argv);
+	
+	/* GEMS initialization and profile manager test */
+	/*
+	gems_components* gems_comp = jammo_gems_init(&argc, &argv);
+	gems_profilemanager_login(gems_comp->pm,1);
+	gems_list_profile_parameters(gems_comp->pm);
+	gems_profilemanager_logout(gems_comp->pm);
+	*/
+	
 	srand (time (NULL)); //We will use rand()
 
 #ifdef N900
@@ -166,9 +210,7 @@ int main(int argc, char** argv) {
 	create_directories();
 
 	/* TODO: Temporary: make sure Mentor classes exists. */
-	type = JAMMO_TYPE_MENTOR;
-	type = JAMMO_TYPE_MENTOR_ACTION;
-	printf("%p %p\n", JAMMO_TYPE_MENTOR, JAMMO_TYPE_MENTOR_ACTION);
+	printf("%ld %ld\n", (long)JAMMO_TYPE_MENTOR, (long)JAMMO_TYPE_MENTOR_ACTION);
 
 	if ((stylesheet = get_jammo_stylesheet())) {
 		tangle_stylesheet_set_default(stylesheet);
@@ -186,6 +228,7 @@ int main(int argc, char** argv) {
 
 		return 2;
 	}
+	g_free(filename);
 	
 	if (!(object = clutter_script_get_object(script, "main"))) {
 		g_warning("Object 'main' not found from the file 'jammo.json'.");
@@ -207,6 +250,8 @@ int main(int argc, char** argv) {
 	clutter_stage_set_key_focus(CLUTTER_STAGE(stage), NULL);
 
 #ifdef N900
+	g_assert(osso_rpc_set_default_cb_f(osso_context, rpc_callback, stage) == OSSO_OK);
+	
 	clutter_stage_set_fullscreen(CLUTTER_STAGE(stage), TRUE);
 #else
 	clutter_actor_set_size(stage, 800, 480);
@@ -237,16 +282,31 @@ int main(int argc, char** argv) {
 	
 	clutter_main();
 
+	g_object_unref(stage);
+	g_object_unref(script);
+	g_object_unref(stylesheet);
+	
+	jammo_meam_cleanup();
+
+	/* GEMS cleanup */
+	//jammo_gems_cleanup(gems_comp);
+
 	return 0;
 }
 
-static void mentor_say_easy(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
-	jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_easy_selected_fi.ogg" );
-}
 
 
-static void mentor_say_advanced(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
-	jammo_mentor_speak(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_advanced_selected_fi.ogg");
+//FIXME: this is copy-pasted from singing-game (solo/duetto and language-selection uses same kind of mechanism)
+static gulong handler_for_mentor_say_selected;
+
+static void mentor_say_what_is_selected(TangleActor *actor, ClutterActorBox *arg1, gpointer user_data){
+	//printf("got '%s'\n",(gchar*)user_data);
+	gchar *filepath1;
+	filepath1 =  g_strdup_printf("/opt/jammo/mentor_speech/mentor%s_selected_fi.ogg", (gchar*)user_data);
+
+	jammo_mentor_speak(jammo_mentor_get_default(), filepath1);
+	g_free(filepath1);
+	g_signal_handler_disconnect (actor,handler_for_mentor_say_selected);
 }
 
 
@@ -271,13 +331,12 @@ void jammo_easy_changed(TangleAction *action, GObject *source, const gchar *trig
 	if (strcmp(name,"easy")==0)
 		{
 		chum_set_easy_game(TRUE);
-		g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_easy), NULL);
+		handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), "_easy");
 		}
 	else if (strcmp(name,"advanced")==0)
 		{
 		chum_set_easy_game(FALSE);
-		g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_advanced), NULL);
-	
+		handler_for_mentor_say_selected=g_signal_connect(view, "show-completed", G_CALLBACK(mentor_say_what_is_selected), "_advanced");
 		}
 
 
