@@ -108,9 +108,7 @@ static void close_themeselection(){
 static gboolean yes_save_clicked ( gpointer data) {
 	printf("yes_save selected\n");
 	save_composition();
-	jammo_mentor_speak(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_save_confirmed_fi.ogg");
-	
-	close_themeselection();
+	jammo_mentor_speak_with_callback(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_save_confirmed_fi.ogg",close_themeselection,NULL);
 	return FALSE;
 }
 
