@@ -133,7 +133,7 @@ static gchar notenames[] ={'c','1','d','2','e','f',
 
 /*This is used when user pass char to instrument.
 It is best that user can use chars when calling instrument*/
-gint get_note(gchar ch){
+static gint get_note(gchar ch){
   int i;
   for (i=0;i<NUMBER_OF_NOTES;i++) {
     if (ch==notenames[i])
